@@ -25,7 +25,7 @@ use CGI;
 use HTTP::Status qw(:constants :is);
 use HTTP::Headers;
 
-our $VERSION = q[476.1.1];
+our $VERSION = q[476.4.2];
 our $CRUD    = { # these map HTTP verbs to $action
 		POST    => 'create',
 		GET     => 'read',
@@ -448,6 +448,15 @@ sub handler {
   my $namespace = $self->namespace($util);
 
   $headers->header('Status', HTTP_OK);
+  $headers->header('X-Generator', 'ClearPress');
+
+  #########
+  # no obvious right place for this
+  #
+  my $lang = $decorator->lang;
+  if($lang && scalar @{$lang}) {
+    $headers->header('Content-Language', join q[,], @{$lang});
+  }
 
   my ($action, $entity, $aspect, $id, $process_request_error);
   eval {
